@@ -4,7 +4,7 @@
 //! @section Copyright
 //
 // This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2022 J. Marcel van der Veer <algol68g@xs4all.nl>.
+// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
 //
 //! @section License
 //
@@ -31,7 +31,7 @@
 
 //! @brief Insert alt equals symbol.
 
-static void insert_alt_equals (NODE_T * p)
+void insert_alt_equals (NODE_T * p)
 {
   NODE_T *q = new_node ();
   *q = *p;
