@@ -4,7 +4,7 @@
 //! @section Copyright
 //
 // This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2022 J. Marcel van der Veer <algol68g@xs4all.nl>.
+// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
 //
 //! @section License
 //
@@ -1133,7 +1133,7 @@ void genie_pow_mp_complex_int (NODE_T * p)
   if (negative) {
     VALUE (&j) = -VALUE (&j);
   }
-  while ((unsigned) expo <= (unsigned) (VALUE (&j))) {
+  while ((unt) expo <= (unt) (VALUE (&j))) {
     if (expo & VALUE (&j)) {
       (void) mul_mp (p, acc, im_z, im_y, digs);
       (void) mul_mp (p, rea, re_z, re_y, digs);
