@@ -4,7 +4,7 @@
 //! @section Copyright
 //
 // This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2022 J. Marcel van der Veer <algol68g@xs4all.nl>.
+// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
 //
 //! @section License
 //
@@ -350,7 +350,8 @@ MP_T *int_to_mp (NODE_T * p, MP_T * z, INT_T k, int digs)
     n++;
   }
   set_mp (z, 0, n, digs);
-  for (int j = 1 + n; j >= 1; j--) {
+  int j;
+  for (j = 1 + n; j >= 1; j--) {
     MP_DIGIT (z, j) = (MP_T) (k % MP_RADIX);
     k /= MP_RADIX;
   }
@@ -359,16 +360,17 @@ MP_T *int_to_mp (NODE_T * p, MP_T * z, INT_T k, int digs)
   return z;
 }
 
-//! @brief Convert unsigned to multi-precison number.
+//! @brief Convert unt to multi-precison number.
 
-MP_T *unsigned_to_mp (NODE_T * p, MP_T * z, UNSIGNED_T k, int digs)
+MP_T *unt_to_mp (NODE_T * p, MP_T * z, UNSIGNED_T k, int digs)
 {
   int m = k, n = 0;
   while ((m /= MP_RADIX) != 0) {
     n++;
   }
   set_mp (z, 0, n, digs);
-  for (int j = 1 + n; j >= 1; j--) {
+  int j;
+  for (j = 1 + n; j >= 1; j--) {
     MP_DIGIT (z, j) = (MP_T) (k % MP_RADIX);
     k /= MP_RADIX;
   }
@@ -390,7 +392,8 @@ INT_T mp_to_int (NODE_T * p, MP_T * z, int digs)
   if (negative) {
     MP_DIGIT (z, 1) = -MP_DIGIT (z, 1);
   }
-  for (int j = 1 + expo; j >= 1; j--) {
+  int j;
+  for (j = 1 + expo; j >= 1; j--) {
     if ((MP_INT_T) MP_DIGIT (z, j) > A68_MAX_INT / weight) {
       diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, M_INT);
       exit_genie (p, A68_RUNTIME_ERROR);
@@ -430,8 +433,8 @@ MP_T *real_to_mp (NODE_T * p, MP_T * z, REAL_T x, int digs)
   }
 // Transport digs of x to the mantissa of z.
   INT_T sum = 0, weight = (MP_RADIX / 10);
-  int j = 1;
-  for (int k = 0; a != 0.0 && j <= digs && k < REAL_DIGITS; k++) {
+  int j = 1, k;
+  for (k = 0; a != 0.0 && j <= digs && k < REAL_DIGITS; k++) {
     REAL_T u = a * 10;
     REAL_T v = floor (u);
     a = u - v;
@@ -464,7 +467,8 @@ REAL_T mp_to_real (NODE_T * p, MP_T * z, int digs)
     return 0;
   } else {
     REAL_T sum = 0, weight = ten_up ((int) (MP_EXPONENT (z) * LOG_MP_RADIX));
-    for (int j = 1; j <= digs && (j - 2) * LOG_MP_RADIX <= REAL_DIG; j++) {
+    int j;
+    for (j = 1; j <= digs && (j - 2) * LOG_MP_RADIX <= REAL_DIG; j++) {
       sum += ABS (MP_DIGIT (z, j)) * weight;
       weight /= MP_RADIX;
     }
@@ -479,7 +483,8 @@ static inline void norm_mp_light (MP_T * w, int k, int digs)
 {
 // Bring every digit back to [0 .. MP_RADIX>.
   MP_T *z = &MP_DIGIT (w, digs);
-  for (int j = digs; j >= k; j--, z--) {
+  int j;
+  for (j = digs; j >= k; j--, z--) {
     if (z[0] >= MP_RADIX) {
       z[0] -= (MP_T) MP_RADIX;
       z[-1] += 1;
@@ -631,7 +636,8 @@ MP_T *lengthen_mp (NODE_T * p, MP_T * z, int digs_z, MP_T * x, int digs_x)
       MP_EXPONENT (z) = MP_EXPONENT (x);
       MP_STATUS (z) = MP_STATUS (x);
     }
-    for (int j = 1 + digs_x; j <= digs_z; j++) {
+    int j;
+    for (j = 1 + digs_x; j <= digs_z; j++) {
       MP_DIGIT (z, j) = (MP_T) 0;
     }
   }
@@ -669,23 +675,24 @@ MP_T *add_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     MP_T *w = nil_mp (p, digs_h);
     if (MP_EXPONENT (x) == MP_EXPONENT (y)) {
       MP_EXPONENT (w) = (MP_T) 1 + MP_EXPONENT (x);
-      for (int j = 1; j <= digs; j++) {
+      int j;
+      for (j = 1; j <= digs; j++) {
         MP_DIGIT (w, j + 1) = MP_DIGIT (x, j) + MP_DIGIT (y, j);
       }
       MP_DIGIT (w, digs_h) = (MP_T) 0;
     } else if (MP_EXPONENT (x) > MP_EXPONENT (y)) {
-      int shl_y = (int) MP_EXPONENT (x) - (int) MP_EXPONENT (y);
+      int j, shl_y = (int) MP_EXPONENT (x) - (int) MP_EXPONENT (y);
       MP_EXPONENT (w) = (MP_T) 1 + MP_EXPONENT (x);
-      for (int j = 1; j < digs_h; j++) {
+      for (j = 1; j < digs_h; j++) {
         int i_y = j - shl_y;
         MP_T x_j = (j > digs ? 0 : MP_DIGIT (x, j));
         MP_T y_j = (i_y <= 0 || i_y > digs ? 0 : MP_DIGIT (y, i_y));
         MP_DIGIT (w, j + 1) = x_j + y_j;
       }
     } else {
-      int shl_x = (int) MP_EXPONENT (y) - (int) MP_EXPONENT (x);
+      int j, shl_x = (int) MP_EXPONENT (y) - (int) MP_EXPONENT (x);
       MP_EXPONENT (w) = (MP_T) 1 + MP_EXPONENT (y);
-      for (int j = 1; j < digs_h; j++) {
+      for (j = 1; j < digs_h; j++) {
         int i_x = j - shl_x;
         MP_T x_j = (i_x <= 0 || i_x > digs ? 0 : MP_DIGIT (x, i_x));
         MP_T y_j = (j > digs ? 0 : MP_DIGIT (y, j));
@@ -734,18 +741,18 @@ MP_T *sub_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
   } else {
 // Subtract.
     BOOL_T negative = A68_FALSE;
-    int fnz, digs_h = 2 + digs;
+    int j, fnz, digs_h = 2 + digs;
     MP_T *w = nil_mp (p, digs_h);
     if (MP_EXPONENT (x) == MP_EXPONENT (y)) {
       MP_EXPONENT (w) = (MP_T) 1 + MP_EXPONENT (x);
-      for (int j = 1; j <= digs; j++) {
+      for (j = 1; j <= digs; j++) {
         MP_DIGIT (w, j + 1) = MP_DIGIT (x, j) - MP_DIGIT (y, j);
       }
       MP_DIGIT (w, digs_h) = (MP_T) 0;
     } else if (MP_EXPONENT (x) > MP_EXPONENT (y)) {
       int shl_y = (int) MP_EXPONENT (x) - (int) MP_EXPONENT (y);
       MP_EXPONENT (w) = (MP_T) 1 + MP_EXPONENT (x);
-      for (int j = 1; j < digs_h; j++) {
+      for (j = 1; j < digs_h; j++) {
         int i_y = j - shl_y;
         MP_T x_j = (j > digs ? 0 : MP_DIGIT (x, j));
         MP_T y_j = (i_y <= 0 || i_y > digs ? 0 : MP_DIGIT (y, i_y));
@@ -754,7 +761,7 @@ MP_T *sub_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     } else {
       int shl_x = (int) MP_EXPONENT (y) - (int) MP_EXPONENT (x);
       MP_EXPONENT (w) = (MP_T) 1 + MP_EXPONENT (y);
-      for (int j = 1; j < digs_h; j++) {
+      for (j = 1; j < digs_h; j++) {
         int i_x = j - shl_x;
         MP_T x_j = (i_x <= 0 || i_x > digs ? 0 : MP_DIGIT (x, i_x));
         MP_T y_j = (j > digs ? 0 : MP_DIGIT (y, j));
@@ -764,14 +771,14 @@ MP_T *sub_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
 // Correct if we subtract large from small.
     if (MP_DIGIT (w, 2) <= 0) {
       fnz = -1;
-      for (int j = 2; j <= digs_h && fnz < 0; j++) {
+      for (j = 2; j <= digs_h && fnz < 0; j++) {
         if (MP_DIGIT (w, j) != 0) {
           fnz = j;
         }
       }
       negative = (BOOL_T) (MP_DIGIT (w, fnz) < 0);
       if (negative) {
-        for (int j = fnz; j <= digs_h; j++) {
+        for (j = fnz; j <= digs_h; j++) {
           MP_DIGIT (w, j) = -MP_DIGIT (w, j);
         }
       }
@@ -779,14 +786,14 @@ MP_T *sub_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
 // Normalise.
     norm_mp_light (w, 2, digs_h);
     fnz = -1;
-    for (int j = 1; j <= digs_h && fnz < 0; j++) {
+    for (j = 1; j <= digs_h && fnz < 0; j++) {
       if (MP_DIGIT (w, j) != 0) {
         fnz = j;
       }
     }
     if (fnz > 1) {
       int j2 = fnz - 1;
-      for (int j = 1; j <= digs_h - j2; j++) {
+      for (j = 1; j <= digs_h - j2; j++) {
         MP_DIGIT (w, j) = MP_DIGIT (w, j + j2);
         MP_DIGIT (w, j + j2) = (MP_T) 0;
       }
@@ -818,14 +825,14 @@ MP_T *mul_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
   }
 // Grammar school algorithm with intermittent normalisation.
   ADDR_T pop_sp = A68_SP;
-  int digs_h = 2 + digs;
+  int i, digs_h = 2 + digs;
   MP_T x_1 = MP_DIGIT (x, 1), y_1 = MP_DIGIT (y, 1);
   MP_DIGIT (x, 1) = ABS (x_1);
   MP_DIGIT (y, 1) = ABS (y_1);
   MP_STATUS (z) = (MP_T) INIT_MASK;
   MP_T *w = lit_mp (p, 0, MP_EXPONENT (x) + MP_EXPONENT (y) + 1, digs_h);
   int oflow = (int) FLOOR_MP ((MP_REAL_T) MAX_REPR_INT / (2 * MP_REAL_RADIX * MP_REAL_RADIX)) - 1;
-  for (int i = digs; i >= 1; i--) {
+  for (i = digs; i >= 1; i--) {
     MP_T yi = MP_DIGIT (y, i);
     if (yi != 0) {
       int k = digs_h - i;
@@ -904,7 +911,8 @@ MP_T *div_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
 // Estimate the denominator. For small MP_RADIX add: MP_DIGIT (y, 4) / MP_REAL_RADIX.
   MP_REAL_T den = (MP_DIGIT (y, 1) * MP_REAL_RADIX + MP_DIGIT (y, 2)) * MP_REAL_RADIX + MP_DIGIT (y, 3);
   MP_T *t = &MP_DIGIT (w, 2);
-  for (int k = 1, len = digs + 2, first = 3; k <= digs + 2; k++, len++, first++, t++) {
+  int k, len, first;
+  for (k = 1, len = digs + 2, first = 3; k <= digs + 2; k++, len++, first++, t++) {
 // Estimate quotient digit.
     MP_REAL_T q, nom = ((t[-1] * MP_REAL_RADIX + t[0]) * MP_REAL_RADIX + t[1]) * MP_REAL_RADIX + (wdigs >= (first + 2) ? t[2] : 0);
     if (nom == 0) {
@@ -917,7 +925,8 @@ MP_T *div_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
         lim = first + nzdigs - 1;
       }
       MP_T *u = t, *v = &MP_DIGIT (y, 1);
-      for (int j = first; j <= lim; j++) {
+      int j;
+      for (j = first; j <= lim; j++) {
         (u++)[0] -= q * (v++)[0];
       }
     }
@@ -1099,13 +1108,13 @@ MP_T *div_mp_digit (NODE_T * p, MP_T * z, MP_T * x, MP_T y, int digs)
   } else if (y == 10) {
     (void) tenth_mp (p, z, x, digs);
   } else {
-    int wdigs = 4 + digs;
+    int k, first, wdigs = 4 + digs;
     MP_T *w = lit_mp (p, 0, MP_EXPONENT (x), wdigs);
     (void) move_mp_part (&MP_DIGIT (w, 2), &MP_DIGIT (x, 1), digs);
 // Estimate the denominator.
     MP_REAL_T den = (MP_REAL_T) y * MP_REAL_RADIX * MP_REAL_RADIX;
     MP_T *t = &MP_DIGIT (w, 2);
-    for (int k = 1, first = 3; k <= digs + 2; k++, first++, t++) {
+    for (k = 1, first = 3; k <= digs + 2; k++, first++, t++) {
 // Estimate quotient digit and correct.
       MP_REAL_T nom = ((t[-1] * MP_REAL_RADIX + t[0]) * MP_REAL_RADIX + t[1]) * MP_REAL_RADIX + (wdigs >= (first + 2) ? t[2] : 0);
       MP_REAL_T q = (MP_T) (MP_INT_T) (nom / den);
@@ -1185,7 +1194,7 @@ MP_T *pow_mp_int (NODE_T * p, MP_T * z, MP_T * x, INT_T n, int digs)
     n = -n;
   }
   bit = 1;
-  while ((unsigned) bit <= (unsigned) n) {
+  while ((unt) bit <= (unt) n) {
     if (n & bit) {
       (void) mul_mp (p, z_g, z_g, x_g, digs_g);
     }
