@@ -4,7 +4,7 @@
 //! @section Copyright
 //
 // This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2022 J. Marcel van der Veer <algol68g@xs4all.nl>.
+// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
 //
 //! @section License
 //
@@ -428,7 +428,6 @@ BOOL_T dont_mark_here (NODE_T * p)
   case UNTIL_SYMBOL:
   case VOID_SYMBOL:
   case WHILE_SYMBOL:
-// and than.
   case SERIAL_CLAUSE:
   case ENQUIRY_CLAUSE:
   case INITIALISER_SERIES:
@@ -812,23 +811,6 @@ TAG_T *new_tag (void)
   return z;
 }
 
-//! @brief New_source_line.
-
-LINE_T *new_source_line (void)
-{
-  LINE_T *z = (LINE_T *) get_fixed_heap_space ((size_t) SIZE_ALIGNED (LINE_T));
-  MARKER (z)[0] = NULL_CHAR;
-  STRING (z) = NO_TEXT;
-  FILENAME (z) = NO_TEXT;
-  DIAGNOSTICS (z) = NO_DIAGNOSTIC;
-  NUMBER (z) = 0;
-  PRINT_STATUS (z) = 0;
-  LIST (z) = A68_TRUE;
-  NEXT (z) = NO_LINE;
-  PREVIOUS (z) = NO_LINE;
-  return z;
-}
-
 //! @brief Make special, internal mode.
 
 void make_special_mode (MOID_T ** n, int m)
