@@ -4,7 +4,7 @@
 //! @section Copyright
 //
 // This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2022 J. Marcel van der Veer <algol68g@xs4all.nl>.
+// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
 //
 //! @section License
 //
@@ -484,7 +484,7 @@ void genie_pq_getisnull (NODE_T * p)
 
 //! @brief Edit error message sting from libpq.
 
-static char *pq_edit (char *str)
+char *pq_edit (char *str)
 {
   if (str == NULL) {
     return "";
