@@ -4,7 +4,7 @@
 //! @section Copyright
 //
 // This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2022 J. Marcel van der Veer <algol68g@xs4all.nl>.
+// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
 //
 //! @section License
 //
@@ -46,7 +46,7 @@
 
 //! @brief Save scanner state, for character look-ahead.
 
-static void save_state (LINE_T * ref_l, char *ref_s, char ch)
+void save_state (LINE_T * ref_l, char *ref_s, char ch)
 {
   SCAN_STATE_L (&A68_JOB) = ref_l;
   SCAN_STATE_S (&A68_JOB) = ref_s;
@@ -55,18 +55,66 @@ static void save_state (LINE_T * ref_l, char *ref_s, char ch)
 
 //! @brief Restore scanner state, for character look-ahead.
 
-static void restore_state (LINE_T ** ref_l, char **ref_s, char *ch)
+void restore_state (LINE_T ** ref_l, char **ref_s, char *ch)
 {
   *ref_l = SCAN_STATE_L (&A68_JOB);
   *ref_s = SCAN_STATE_S (&A68_JOB);
   *ch = SCAN_STATE_C (&A68_JOB);
 }
 
+//! @brief New_source_line.
+
+LINE_T *new_source_line (void)
+{
+  LINE_T *z = (LINE_T *) get_fixed_heap_space ((size_t) SIZE_ALIGNED (LINE_T));
+  MARKER (z)[0] = NULL_CHAR;
+  STRING (z) = NO_TEXT;
+  FILENAME (z) = NO_TEXT;
+  DIAGNOSTICS (z) = NO_DIAGNOSTIC;
+  NUMBER (z) = 0;
+  PRINT_STATUS (z) = 0;
+  LIST (z) = A68_TRUE;
+  NEXT (z) = NO_LINE;
+  PREVIOUS (z) = NO_LINE;
+  return z;
+}
+
+//! @brief Append a source line to the internal source file.
+
+void append_source_line (char *str, LINE_T ** ref_l, int *line_num, char *filename)
+{
+  LINE_T *z = new_source_line ();
+// Allow shell command in first line, f.i. "#!/usr/share/bin/a68g".
+  if (*line_num == 1) {
+    if (strlen (str) >= 2 && strncmp (str, "#!", 2) == 0) {
+      ABEND (strstr (str, "run-script") != NO_TEXT, ERROR_SHELL_SCRIPT, __func__);
+      (*line_num)++;
+      return;
+    }
+  }
+// Link line into the chain.
+  STRING (z) = new_fixed_string (str);
+  FILENAME (z) = filename;
+  NUMBER (z) = (*line_num)++;
+  PRINT_STATUS (z) = NOT_PRINTED;
+  LIST (z) = A68_TRUE;
+  DIAGNOSTICS (z) = NO_DIAGNOSTIC;
+  NEXT (z) = NO_LINE;
+  PREVIOUS (z) = *ref_l;
+  if (TOP_LINE (&A68_JOB) == NO_LINE) {
+    TOP_LINE (&A68_JOB) = z;
+  }
+  if (*ref_l != NO_LINE) {
+    NEXT (*ref_l) = z;
+  }
+  *ref_l = z;
+}
+
 // Scanner, tokenises the source code.
 
 //! @brief Whether ch is unworthy.
 
-static void unworthy (LINE_T * u, char *v, char ch)
+void unworthy (LINE_T * u, char *v, char ch)
 {
   if (IS_PRINT (ch)) {
     ASSERT (snprintf (A68 (edit_line), SNPRINTF_SIZE, "*%s", ERROR_UNWORTHY_CHARACTER) >= 0);
@@ -78,7 +126,7 @@ static void unworthy (LINE_T * u, char *v, char ch)
 
 //! @brief Concatenate lines that terminate in '\' with next line.
 
-static void concatenate_lines (LINE_T * top)
+void concatenate_lines (LINE_T * top)
 {
   LINE_T *q;
 // Work from bottom backwards.
@@ -102,9 +150,9 @@ static void concatenate_lines (LINE_T * top)
 
 //! @brief Whether u is bold tag v, independent of stropping regime.
 
-static BOOL_T is_bold (char *u, char *v)
+BOOL_T is_bold (char *u, char *v)
 {
-  unsigned len = (unsigned) strlen (v);
+  unt len = (unt) strlen (v);
   if (OPTION_STROPPING (&A68_JOB) == QUOTE_STROPPING) {
     if (u[0] == '\'') {
       return (BOOL_T) (strncmp (++u, v, len) == 0 && u[len] == '\'');
@@ -118,7 +166,7 @@ static BOOL_T is_bold (char *u, char *v)
 
 //! @brief Skip string.
 
-static BOOL_T skip_string (LINE_T ** top, char **ch)
+BOOL_T skip_string (LINE_T ** top, char **ch)
 {
   LINE_T *u = *top;
   char *v = *ch;
@@ -147,7 +195,7 @@ static BOOL_T skip_string (LINE_T ** top, char **ch)
 
 //! @brief Skip comment.
 
-static BOOL_T skip_comment (LINE_T ** top, char **ch, int delim)
+BOOL_T skip_comment (LINE_T ** top, char **ch, int delim)
 {
   LINE_T *u = *top;
   char *v = *ch;
@@ -182,7 +230,7 @@ static BOOL_T skip_comment (LINE_T ** top, char **ch, int delim)
 
 //! @brief Skip rest of pragmat.
 
-static BOOL_T skip_pragmat (LINE_T ** top, char **ch, int delim, BOOL_T whitespace)
+BOOL_T skip_pragmat (LINE_T ** top, char **ch, int delim, BOOL_T whitespace)
 {
   LINE_T *u = *top;
   char *v = *ch;
@@ -221,7 +269,7 @@ static BOOL_T skip_pragmat (LINE_T ** top, char **ch, int delim, BOOL_T whitespa
 
 //! @brief Return pointer to next token within pragmat.
 
-static char *get_pragmat_item (LINE_T ** top, char **ch)
+char *get_pragmat_item (LINE_T ** top, char **ch)
 {
   LINE_T *u = *top;
   char *v = *ch;
@@ -353,6 +401,11 @@ void include_files (LINE_T * top)
 // The file gets inserted before the line containing the pragmat. In this way
 // correct line numbers are preserved which helps diagnostics. A file that has
 // been included will not be included a second time - it will be ignored. 
+// A rigorous fail-safe, but there is no mechanism to prevent recursive includes 
+// in A68 source code. User reports do not indicate sophisticated use of INCLUDE, 
+// so this is fine for now.
+// TODO - some day we might need `app', analogous to `cpp'.
+//
   BOOL_T make_pass = A68_TRUE;
   while (make_pass) {
     LINE_T *s, *t, *u = top;
@@ -371,10 +424,8 @@ void include_files (LINE_T * top)
         char *fbuf, delim;
         char fnb[BUFFER_SIZE], *fn;
 // Skip to filename.
-        if (streq (item, "INCLUDE") == 0) {
-          v = &v[strlen ("INCLUDE")];
-        } else {
-          v = &v[strlen ("READ")];
+        while (IS_ALPHA (v[0])) {
+          v++;
         }
         while (IS_SPACE (v[0])) {
           v++;
@@ -405,28 +456,43 @@ void include_files (LINE_T * top)
 // Insist that the pragmat is closed properly.
         v = &v[1];
         SCAN_ERROR (!skip_pragmat (&u, &v, pr_lim, A68_TRUE), start_l, start_c, ERROR_UNTERMINATED_PRAGMAT);
-// Filename valid?.
         SCAN_ERROR (n == 0, start_l, start_c, ERROR_INCORRECT_FILENAME);
+// Make the name relative to the position of the source file (C preprocessor standard).
+        if (FILENAME (u) != NO_TEXT) {
+          fn = a68_relpath (a68_dirname (FILENAME (u)), a68_dirname (fnb), a68_basename (fnb));
+        } else {
+          fn = a68_relpath (FILE_PATH (&A68_JOB), a68_dirname (fnb), a68_basename (fnb));
+        }
+// Do not check errno, since errno may be undefined here after a successful call.
+        if (fn != NO_TEXT) {
+          bufcpy (fnb, fn, BUFFER_SIZE);
+        } else {
+          char err[PATH_MAX + 1];
+          bufcpy (err, ERROR_SOURCE_FILE_OPEN, PATH_MAX);
+          bufcat (err, " ", PATH_MAX);
+          bufcat (err, fnb, PATH_MAX);
+          SCAN_ERROR (A68_TRUE, NO_LINE, NO_TEXT, err);
+        }
         fnwid = (int) strlen (fnb) + 1;
         fn = (char *) get_fixed_heap_space ((size_t) fnwid);
         bufcpy (fn, fnb, fnwid);
-// Recursive include? Then *ignore* the file.
+// Ignore the file when included more than once.
         for (t = top; t != NO_LINE; t = NEXT (t)) {
           if (strcmp (FILENAME (t), fn) == 0) {
-            goto search_next_pragmat;   // Eeek!
+            goto search_next_pragmat;
           }
         }
+        t = NO_LINE;
 // Access the file.
         errno = 0;
         fd = open (fn, O_RDONLY | O_BINARY);
         ASSERT (snprintf (A68 (edit_line), SNPRINTF_SIZE, "*%s \"%s\"", ERROR_SOURCE_FILE_OPEN, fn) >= 0);
         SCAN_ERROR (fd == -1, start_l, start_c, A68 (edit_line));
-// Access the file.
         errno = 0;
         fsize = (int) lseek (fd, 0, SEEK_END);
         ASSERT (fsize >= 0);
         SCAN_ERROR (errno != 0, start_l, start_c, ERROR_FILE_READ);
-        fbuf = (char *) get_temp_heap_space ((unsigned) (8 + fsize));
+        fbuf = (char *) get_temp_heap_space ((unt) (8 + fsize));
         errno = 0;
         ASSERT (lseek (fd, 0, SEEK_SET) >= 0);
         SCAN_ERROR (errno != 0, start_l, start_c, ERROR_FILE_READ);
@@ -436,7 +502,7 @@ void include_files (LINE_T * top)
 // Buffer still usable?.
         if (fsize > A68_PARSER (max_scan_buf_length)) {
           A68_PARSER (max_scan_buf_length) = fsize;
-          A68_PARSER (scan_buf) = (char *) get_temp_heap_space ((unsigned) (8 + A68_PARSER (max_scan_buf_length)));
+          A68_PARSER (scan_buf) = (char *) get_temp_heap_space ((unt) (8 + A68_PARSER (max_scan_buf_length)));
         }
 // Link all lines into the list.
         linum = 1;
@@ -476,37 +542,6 @@ void include_files (LINE_T * top)
   }
 }
 
-//! @brief Append a source line to the internal source file.
-
-void append_source_line (char *str, LINE_T ** ref_l, int *line_num, char *filename)
-{
-  LINE_T *z = new_source_line ();
-// Allow shell command in first line, f.i. "#!/usr/share/bin/a68g".
-  if (*line_num == 1) {
-    if (strlen (str) >= 2 && strncmp (str, "#!", 2) == 0) {
-      ABEND (strstr (str, "run-script") != NO_TEXT, ERROR_SHELL_SCRIPT, __func__);
-      (*line_num)++;
-      return;
-    }
-  }
-// Link line into the chain.
-  STRING (z) = new_fixed_string (str);
-  FILENAME (z) = filename;
-  NUMBER (z) = (*line_num)++;
-  PRINT_STATUS (z) = NOT_PRINTED;
-  LIST (z) = A68_TRUE;
-  DIAGNOSTICS (z) = NO_DIAGNOSTIC;
-  NEXT (z) = NO_LINE;
-  PREVIOUS (z) = *ref_l;
-  if (TOP_LINE (&A68_JOB) == NO_LINE) {
-    TOP_LINE (&A68_JOB) = z;
-  }
-  if (*ref_l != NO_LINE) {
-    NEXT (*ref_l) = z;
-  }
-  *ref_l = z;
-}
-
 //! @brief Size of source file.
 
 int get_source_size (void)
@@ -534,16 +569,16 @@ BOOL_T read_script_file (void)
 {
   LINE_T *ref_l = NO_LINE;
   int k, n, num;
-  unsigned len;
+  unt len;
   BOOL_T file_end = A68_FALSE;
   char filename[BUFFER_SIZE], linenum[BUFFER_SIZE];
   char ch, *fn, *line;
-  char *buffer = (char *) get_temp_heap_space ((unsigned) (8 + A68_PARSER (source_file_size)));
+  char *buffer = (char *) get_temp_heap_space ((unt) (8 + A68_PARSER (source_file_size)));
   FILE_T source = FILE_SOURCE_FD (&A68_JOB);
   ABEND (source == -1, ERROR_ACTION, __func__);
   buffer[0] = NULL_CHAR;
   n = 0;
-  len = (unsigned) (8 + A68_PARSER (source_file_size));
+  len = (unt) (8 + A68_PARSER (source_file_size));
   buffer = (char *) get_temp_heap_space (len);
   ASSERT (lseek (source, 0, SEEK_SET) >= 0);
   while (!file_end) {
@@ -577,7 +612,7 @@ BOOL_T read_script_file (void)
     while (ch != NEWLINE_CHAR) {
       buffer[n++] = ch;
       ASSERT (io_read (source, &ch, 1) == 1);
-      ABEND ((unsigned) n >= len, ERROR_ACTION, __func__);
+      ABEND ((unt) n >= len, ERROR_ACTION, __func__);
     }
     buffer[n++] = NEWLINE_CHAR;
     buffer[n] = NULL_CHAR;
@@ -609,7 +644,7 @@ BOOL_T read_source_file (void)
 // Read the file into a single buffer, so we save on system calls.
   line_num = 1;
   errno = 0;
-  buffer = (char *) get_temp_heap_space ((unsigned) (8 + A68_PARSER (source_file_size)));
+  buffer = (char *) get_temp_heap_space ((unt) (8 + A68_PARSER (source_file_size)));
   ABEND (errno != 0 || buffer == NO_TEXT, ERROR_ALLOCATION, __func__);
   ASSERT (lseek (f, 0, SEEK_SET) >= 0);
   ABEND (errno != 0, ERROR_ACTION, __func__);
@@ -1491,13 +1526,13 @@ BOOL_T lexical_analyser (void)
     return A68_FALSE;
   }
   if (OPTION_RUN_SCRIPT (&A68_JOB)) {
-    A68_PARSER (scan_buf) = (char *) get_temp_heap_space ((unsigned) (8 + A68_PARSER (max_scan_buf_length)));
+    A68_PARSER (scan_buf) = (char *) get_temp_heap_space ((unt) (8 + A68_PARSER (max_scan_buf_length)));
     if (!read_script_file ()) {
       return A68_FALSE;
     }
   } else {
     A68_PARSER (max_scan_buf_length) += KILOBYTE;       // for the environ, more than enough
-    A68_PARSER (scan_buf) = (char *) get_temp_heap_space ((unsigned) A68_PARSER (max_scan_buf_length));
+    A68_PARSER (scan_buf) = (char *) get_temp_heap_space ((unt) A68_PARSER (max_scan_buf_length));
 // Errors in file?.
     if (!read_source_file ()) {
       return A68_FALSE;
