@@ -4,7 +4,7 @@
 //! @section Copyright
 //
 // This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2022 J. Marcel van der Veer <algol68g@xs4all.nl>.
+// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
 //
 //! @section License
 //
@@ -354,7 +354,7 @@ void genie_first_random (NODE_T * p)
 {
   A68_INT i;
   POP_OBJECT (p, &i, A68_INT);
-  init_rng ((unsigned) VALUE (&i));
+  init_rng ((unt) VALUE (&i));
 }
 
 // @brief PROC REAL next random
