@@ -4,7 +4,7 @@
 //! @section Copyright
 //
 // This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2022 J. Marcel van der Veer <algol68g@xs4all.nl>.
+// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
 //
 //! @section License
 //
@@ -23,6 +23,246 @@
 #include "a68g-genie.h"
 #include "a68g-prelude.h"
 
+//! @brief Push description for diagonal of square matrix.
+
+PROP_T genie_diagonal_function (NODE_T * p)
+{
+  NODE_T *q = SUB (p);
+  ADDR_T scope = PRIMAL_SCOPE;
+  PROP_T self;
+  A68_ROW row, new_row;
+  int k = 0;
+  BOOL_T name = (BOOL_T) (IS_REF (MOID (p)));
+  A68_ARRAY *arr, new_arr;
+  A68_TUPLE *tup1, *tup2, new_tup;
+  MOID_T *m;
+  if (IS (q, TERTIARY)) {
+    A68_INT x;
+    EXECUTE_UNIT (q);
+    POP_OBJECT (p, &x, A68_INT);
+    k = VALUE (&x);
+    FORWARD (q);
+  }
+  EXECUTE_UNIT (NEXT (q));
+  m = (name ? SUB_MOID (NEXT (q)) : MOID (NEXT (q)));
+  if (name) {
+    A68_REF z;
+    POP_REF (p, &z);
+    CHECK_REF (p, z, MOID (SUB (p)));
+    scope = REF_SCOPE (&z);
+    PUSH_REF (p, *DEREF (A68_REF, &z));
+  }
+  POP_OBJECT (p, &row, A68_ROW);
+  GET_DESCRIPTOR2 (arr, tup1, tup2, &row);
+  if (ROW_SIZE (tup1) != ROW_SIZE (tup2)) {
+    diagnostic (A68_RUNTIME_ERROR, p, ERROR_NO_SQUARE_MATRIX, m);
+    exit_genie (p, A68_RUNTIME_ERROR);
+  }
+  if (ABS (k) >= ROW_SIZE (tup1)) {
+    diagnostic (A68_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
+    exit_genie (p, A68_RUNTIME_ERROR);
+  }
+  m = (name ? SUB_MOID (p) : MOID (p));
+  new_row = heap_generator (p, m, DESCRIPTOR_SIZE (1));
+  DIM (&new_arr) = 1;
+  MOID (&new_arr) = m;
+  ELEM_SIZE (&new_arr) = ELEM_SIZE (arr);
+  SLICE_OFFSET (&new_arr) = SLICE_OFFSET (arr);
+  FIELD_OFFSET (&new_arr) = FIELD_OFFSET (arr);
+  ARRAY (&new_arr) = ARRAY (arr);
+  LWB (&new_tup) = 1;
+  UPB (&new_tup) = ROW_SIZE (tup1) - ABS (k);
+  SHIFT (&new_tup) = SHIFT (tup1) + SHIFT (tup2) - k * SPAN (tup2);
+  if (k < 0) {
+    SHIFT (&new_tup) -= (-k) * (SPAN (tup1) + SPAN (tup2));
+  }
+  SPAN (&new_tup) = SPAN (tup1) + SPAN (tup2);
+  K (&new_tup) = 0;
+  PUT_DESCRIPTOR (new_arr, new_tup, &new_row);
+  if (name) {
+    A68_REF ref_new = heap_generator (p, MOID (p), A68_REF_SIZE);
+    *DEREF (A68_REF, &ref_new) = new_row;
+    REF_SCOPE (&ref_new) = scope;
+    PUSH_REF (p, ref_new);
+  } else {
+    PUSH_OBJECT (p, new_row, A68_ROW);
+  }
+  UNIT (&self) = genie_diagonal_function;
+  SOURCE (&self) = p;
+  return self;
+}
+
+//! @brief Push description for transpose of matrix.
+
+PROP_T genie_transpose_function (NODE_T * p)
+{
+  NODE_T *q = SUB (p);
+  ADDR_T scope = PRIMAL_SCOPE;
+  PROP_T self;
+  A68_ROW row, new_row;
+  BOOL_T name = (BOOL_T) (IS_REF (MOID (p)));
+  A68_ARRAY *arr, new_arr;
+  A68_TUPLE *tup1, *tup2, new_tup1, new_tup2;
+  MOID_T *m;
+  EXECUTE_UNIT (NEXT (q));
+  m = (name ? SUB_MOID (NEXT (q)) : MOID (NEXT (q)));
+  if (name) {
+    A68_REF z;
+    POP_REF (p, &z);
+    CHECK_REF (p, z, MOID (SUB (p)));
+    scope = REF_SCOPE (&z);
+    PUSH_REF (p, *DEREF (A68_REF, &z));
+  }
+  POP_OBJECT (p, &row, A68_ROW);
+  GET_DESCRIPTOR2 (arr, tup1, tup2, &row);
+  new_row = heap_generator (p, m, DESCRIPTOR_SIZE (2));
+  new_arr = *arr;
+  new_tup1 = *tup2;
+  new_tup2 = *tup1;
+  PUT_DESCRIPTOR2 (new_arr, new_tup1, new_tup2, &new_row);
+  if (name) {
+    A68_REF ref_new = heap_generator (p, MOID (p), A68_REF_SIZE);
+    *DEREF (A68_REF, &ref_new) = new_row;
+    REF_SCOPE (&ref_new) = scope;
+    PUSH_REF (p, ref_new);
+  } else {
+    PUSH_OBJECT (p, new_row, A68_ROW);
+  }
+  UNIT (&self) = genie_transpose_function;
+  SOURCE (&self) = p;
+  return self;
+}
+
+//! @brief Push description for row vector.
+
+PROP_T genie_row_function (NODE_T * p)
+{
+  NODE_T *q = SUB (p);
+  ADDR_T scope = PRIMAL_SCOPE;
+  PROP_T self;
+  A68_ROW row, new_row;
+  int k = 1;
+  BOOL_T name = (BOOL_T) (IS_REF (MOID (p)));
+  A68_ARRAY *arr, new_arr;
+  A68_TUPLE tup1, tup2, *tup;
+  MOID_T *m;
+  if (IS (q, TERTIARY)) {
+    A68_INT x;
+    EXECUTE_UNIT (q);
+    POP_OBJECT (p, &x, A68_INT);
+    k = VALUE (&x);
+    FORWARD (q);
+  }
+  EXECUTE_UNIT (NEXT (q));
+  m = (name ? SUB_MOID (NEXT (q)) : MOID (NEXT (q)));
+  if (name) {
+    A68_REF z;
+    POP_REF (p, &z);
+    CHECK_REF (p, z, MOID (SUB (p)));
+    scope = REF_SCOPE (&z);
+    PUSH_REF (p, *DEREF (A68_REF, &z));
+  }
+  POP_OBJECT (p, &row, A68_ROW);
+  GET_DESCRIPTOR (arr, tup, &row);
+  if (DIM (arr) != 1) {
+    diagnostic (A68_RUNTIME_ERROR, p, ERROR_NO_VECTOR, m, PRIMARY);
+    exit_genie (p, A68_RUNTIME_ERROR);
+  }
+  m = (name ? SUB_MOID (p) : MOID (p));
+  new_row = heap_generator (p, m, DESCRIPTOR_SIZE (2));
+  DIM (&new_arr) = 2;
+  MOID (&new_arr) = m;
+  ELEM_SIZE (&new_arr) = ELEM_SIZE (arr);
+  SLICE_OFFSET (&new_arr) = SLICE_OFFSET (arr);
+  FIELD_OFFSET (&new_arr) = FIELD_OFFSET (arr);
+  ARRAY (&new_arr) = ARRAY (arr);
+  LWB (&tup1) = k;
+  UPB (&tup1) = k;
+  SPAN (&tup1) = 1;
+  SHIFT (&tup1) = k * SPAN (&tup1);
+  K (&tup1) = 0;
+  LWB (&tup2) = 1;
+  UPB (&tup2) = ROW_SIZE (tup);
+  SPAN (&tup2) = SPAN (tup);
+  SHIFT (&tup2) = SPAN (tup);
+  K (&tup2) = 0;
+  PUT_DESCRIPTOR2 (new_arr, tup1, tup2, &new_row);
+  if (name) {
+    A68_REF ref_new = heap_generator (p, MOID (p), A68_REF_SIZE);
+    *DEREF (A68_REF, &ref_new) = new_row;
+    REF_SCOPE (&ref_new) = scope;
+    PUSH_REF (p, ref_new);
+  } else {
+    PUSH_OBJECT (p, new_row, A68_ROW);
+  }
+  UNIT (&self) = genie_row_function;
+  SOURCE (&self) = p;
+  return self;
+}
+
+//! @brief Push description for column vector.
+
+PROP_T genie_column_function (NODE_T * p)
+{
+  NODE_T *q = SUB (p);
+  ADDR_T scope = PRIMAL_SCOPE;
+  PROP_T self;
+  A68_ROW row, new_row;
+  int k = 1;
+  BOOL_T name = (BOOL_T) (IS_REF (MOID (p)));
+  A68_ARRAY *arr, new_arr;
+  A68_TUPLE tup1, tup2, *tup;
+  MOID_T *m;
+  if (IS (q, TERTIARY)) {
+    A68_INT x;
+    EXECUTE_UNIT (q);
+    POP_OBJECT (p, &x, A68_INT);
+    k = VALUE (&x);
+    FORWARD (q);
+  }
+  EXECUTE_UNIT (NEXT (q));
+  m = (name ? SUB_MOID (NEXT (q)) : MOID (NEXT (q)));
+  if (name) {
+    A68_REF z;
+    POP_REF (p, &z);
+    CHECK_REF (p, z, MOID (SUB (p)));
+    scope = REF_SCOPE (&z);
+    PUSH_REF (p, *DEREF (A68_REF, &z));
+  }
+  POP_OBJECT (p, &row, A68_ROW);
+  GET_DESCRIPTOR (arr, tup, &row);
+  m = (name ? SUB_MOID (p) : MOID (p));
+  new_row = heap_generator (p, m, DESCRIPTOR_SIZE (2));
+  DIM (&new_arr) = 2;
+  MOID (&new_arr) = m;
+  ELEM_SIZE (&new_arr) = ELEM_SIZE (arr);
+  SLICE_OFFSET (&new_arr) = SLICE_OFFSET (arr);
+  FIELD_OFFSET (&new_arr) = FIELD_OFFSET (arr);
+  ARRAY (&new_arr) = ARRAY (arr);
+  LWB (&tup1) = 1;
+  UPB (&tup1) = ROW_SIZE (tup);
+  SPAN (&tup1) = SPAN (tup);
+  SHIFT (&tup1) = SPAN (tup);
+  K (&tup1) = 0;
+  LWB (&tup2) = k;
+  UPB (&tup2) = k;
+  SPAN (&tup2) = 1;
+  SHIFT (&tup2) = k * SPAN (&tup2);
+  K (&tup2) = 0;
+  PUT_DESCRIPTOR2 (new_arr, tup1, tup2, &new_row);
+  if (name) {
+    A68_REF ref_new = heap_generator (p, MOID (p), A68_REF_SIZE);
+    *DEREF (A68_REF, &ref_new) = new_row;
+    REF_SCOPE (&ref_new) = scope;
+    PUSH_REF (p, ref_new);
+  } else {
+    PUSH_OBJECT (p, new_row, A68_ROW);
+  }
+  UNIT (&self) = genie_column_function;
+  SOURCE (&self) = p;
+  return self;
+}
+
 #if defined (HAVE_GSL)
 
 static NODE_T *error_node = NO_NODE;
@@ -49,7 +289,7 @@ void torrix_error_handler (const char *reason, const char *file, int line, int g
 
 //! @brief Detect math errors, mainly in BLAS functions.
 
-static void torrix_test_error (int rc)
+void torrix_test_error (int rc)
 {
   if (rc != 0) {
     torrix_error_handler ("math error", "", 0, rc);
@@ -58,7 +298,7 @@ static void torrix_test_error (int rc)
 
 //! @brief Pop [] INT on the stack as gsl_permutation.
 
-static gsl_permutation *pop_permutation (NODE_T * p, BOOL_T get)
+gsl_permutation *pop_permutation (NODE_T * p, BOOL_T get)
 {
   A68_REF desc;
   A68_ARRAY *arr;
@@ -87,7 +327,7 @@ static gsl_permutation *pop_permutation (NODE_T * p, BOOL_T get)
 
 //! @brief Push gsl_permutation on the stack as [] INT.
 
-static void push_permutation (NODE_T * p, gsl_permutation * v)
+void push_permutation (NODE_T * p, gsl_permutation * v)
 {
   A68_REF desc, row;
   A68_ARRAY arr;
@@ -109,7 +349,7 @@ static void push_permutation (NODE_T * p, gsl_permutation * v)
 
 //! @brief Pop [] REAL on the stack as gsl_vector.
 
-static gsl_vector *pop_vector (NODE_T * p, BOOL_T get)
+gsl_vector *pop_vector (NODE_T * p, BOOL_T get)
 {
   A68_REF desc;
   A68_ARRAY *arr;
@@ -138,7 +378,7 @@ static gsl_vector *pop_vector (NODE_T * p, BOOL_T get)
 
 //! @brief Push gsl_vector on the stack as [] REAL.
 
-static void push_vector (NODE_T * p, gsl_vector * v)
+void push_vector (NODE_T * p, gsl_vector * v)
 {
   A68_REF desc, row;
   A68_ARRAY arr;
@@ -161,7 +401,7 @@ static void push_vector (NODE_T * p, gsl_vector * v)
 
 //! @brief Pop [,] REAL on the stack as gsl_matrix.
 
-static gsl_matrix *pop_matrix (NODE_T * p, BOOL_T get)
+gsl_matrix *pop_matrix (NODE_T * p, BOOL_T get)
 {
   A68_REF desc;
   A68_ARRAY *arr;
@@ -195,7 +435,7 @@ static gsl_matrix *pop_matrix (NODE_T * p, BOOL_T get)
 
 //! @brief Push gsl_matrix on the stack as [,] REAL.
 
-static void push_matrix (NODE_T * p, gsl_matrix * a)
+void push_matrix (NODE_T * p, gsl_matrix * a)
 {
   A68_REF desc, row;
   A68_ARRAY arr;
@@ -239,7 +479,7 @@ static void push_matrix (NODE_T * p, gsl_matrix * a)
 
 //! @brief Pop [] COMPLEX on the stack as gsl_vector_complex.
 
-static gsl_vector_complex *pop_vector_complex (NODE_T * p, BOOL_T get)
+gsl_vector_complex *pop_vector_complex (NODE_T * p, BOOL_T get)
 {
   A68_REF desc;
   A68_ARRAY *arr;
@@ -272,7 +512,7 @@ static gsl_vector_complex *pop_vector_complex (NODE_T * p, BOOL_T get)
 
 //! @brief Push gsl_vector_complex on the stack as [] COMPLEX.
 
-static void push_vector_complex (NODE_T * p, gsl_vector_complex * v)
+void push_vector_complex (NODE_T * p, gsl_vector_complex * v)
 {
   A68_REF desc, row;
   A68_ARRAY arr;
@@ -299,7 +539,7 @@ static void push_vector_complex (NODE_T * p, gsl_vector_complex * v)
 
 //! @brief Pop [,] COMPLEX on the stack as gsl_matrix_complex.
 
-static gsl_matrix_complex *pop_matrix_complex (NODE_T * p, BOOL_T get)
+gsl_matrix_complex *pop_matrix_complex (NODE_T * p, BOOL_T get)
 {
   A68_REF desc;
   A68_ARRAY *arr;
@@ -336,7 +576,7 @@ static gsl_matrix_complex *pop_matrix_complex (NODE_T * p, BOOL_T get)
 
 //! @brief Push gsl_matrix_complex on the stack as [,] COMPLEX.
 
-static void push_matrix_complex (NODE_T * p, gsl_matrix_complex * a)
+void push_matrix_complex (NODE_T * p, gsl_matrix_complex * a)
 {
   A68_REF desc, row;
   A68_ARRAY arr;
@@ -384,7 +624,7 @@ static void push_matrix_complex (NODE_T * p, gsl_matrix_complex * a)
 
 //! @brief Generically perform operation and assign result (+:=, -:=, ...) .
 
-static void op_ab (NODE_T * p, MOID_T * m, MOID_T * n, GPROC * op)
+void op_ab_torrix (NODE_T * p, MOID_T * m, MOID_T * n, GPROC * op)
 {
   ADDR_T parm_size = SIZE (m) + SIZE (n);
   A68_REF dst, src, *save = (A68_REF *) STACK_OFFSET (-parm_size);
@@ -395,7 +635,11 @@ static void op_ab (NODE_T * p, MOID_T * m, MOID_T * n, GPROC * op)
   STATUS (&src) = (STATUS_MASK_T) (INIT_MASK | IN_STACK_MASK);
   OFFSET (&src) = A68_SP - parm_size;
   (*op) (p);
-  genie_store (p, n, &dst, &src);
+  if (IS_REF (m)) {
+    genie_store (p, SUB (m), &dst, &src);
+  } else {
+    ABEND (A68_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+  }
   *save = dst;
 }
 
@@ -488,14 +732,16 @@ void genie_matrix_minus (NODE_T * p)
 void genie_matrix_transpose (NODE_T * p)
 {
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
-  gsl_matrix *a;
+  gsl_matrix *a, *t;
   int rc;
   error_node = p;
   a = pop_matrix (p, A68_TRUE);
-  rc = gsl_matrix_transpose (a);
+  t = gsl_matrix_alloc (SIZE2(a), SIZE1(a));
+  rc = gsl_matrix_transpose_memcpy (t, a);
   torrix_test_error (rc);
-  push_matrix (p, a);
+  push_matrix (p, t);
   gsl_matrix_free (a);
+  gsl_matrix_free (t);
   (void) gsl_set_error_handler (save_handler);
 }
 
@@ -504,14 +750,16 @@ void genie_matrix_transpose (NODE_T * p)
 void genie_matrix_complex_transpose (NODE_T * p)
 {
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
-  gsl_matrix_complex *a;
+  gsl_matrix_complex *a, *t;
   int rc;
   error_node = p;
   a = pop_matrix_complex (p, A68_TRUE);
-  rc = gsl_matrix_complex_transpose (a);
+  t = gsl_matrix_complex_alloc (SIZE2(a), SIZE1(a));
+  rc =  gsl_matrix_complex_transpose_memcpy (t, a);
   torrix_test_error (rc);
   push_matrix_complex (p, a);
   gsl_matrix_complex_free (a);
+  gsl_matrix_complex_free (t);
   (void) gsl_set_error_handler (save_handler);
 }
 
@@ -749,14 +997,14 @@ void genie_vector_ne (NODE_T * p)
 
 void genie_vector_plusab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_REAL, M_ROW_REAL, genie_vector_add);
+  op_ab_torrix (p, M_REF_ROW_REAL, M_ROW_REAL, genie_vector_add);
 }
 
 //! @brief OP -:= = (REF [] REAL, [] REAL) REF [] REAL
 
 void genie_vector_minusab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_REAL, M_ROW_REAL, genie_vector_sub);
+  op_ab_torrix (p, M_REF_ROW_REAL, M_ROW_REAL, genie_vector_sub);
 }
 
 //! @brief OP + = ([, ] REAL, [, ] REAL) [, ] REAL
@@ -825,14 +1073,14 @@ void genie_matrix_ne (NODE_T * p)
 
 void genie_matrix_plusab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_ROW_REAL, M_ROW_ROW_REAL, genie_matrix_add);
+  op_ab_torrix (p, M_REF_ROW_ROW_REAL, M_ROW_ROW_REAL, genie_matrix_add);
 }
 
 //! @brief OP -:= = (REF [, ] REAL, [, ] REAL) [, ] REAL
 
 void genie_matrix_minusab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_ROW_REAL, M_ROW_ROW_REAL, genie_matrix_sub);
+  op_ab_torrix (p, M_REF_ROW_ROW_REAL, M_ROW_ROW_REAL, genie_matrix_sub);
 }
 
 //! @brief OP + = ([] COMPLEX, [] COMPLEX) [] COMPLEX
@@ -907,14 +1155,14 @@ void genie_vector_complex_ne (NODE_T * p)
 
 void genie_vector_complex_plusab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_COMPLEX, M_ROW_COMPLEX, genie_vector_complex_add);
+  op_ab_torrix (p, M_REF_ROW_COMPLEX, M_ROW_COMPLEX, genie_vector_complex_add);
 }
 
 //! @brief OP -:= = (REF [] COMPLEX, [] COMPLEX) [] COMPLEX
 
 void genie_vector_complex_minusab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_COMPLEX, M_ROW_COMPLEX, genie_vector_complex_sub);
+  op_ab_torrix (p, M_REF_ROW_COMPLEX, M_ROW_COMPLEX, genie_vector_complex_sub);
 }
 
 //! @brief OP + = ([, ] COMPLEX, [, ] COMPLEX) [, ] COMPLEX
@@ -983,14 +1231,14 @@ void genie_matrix_complex_ne (NODE_T * p)
 
 void genie_matrix_complex_plusab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_ROW_COMPLEX, M_ROW_ROW_COMPLEX, genie_matrix_complex_add);
+  op_ab_torrix (p, M_REF_ROW_ROW_COMPLEX, M_ROW_ROW_COMPLEX, genie_matrix_complex_add);
 }
 
 //! @brief OP -:= = (REF [, ] COMPLEX, [, ] COMPLEX) [, ] COMPLEX
 
 void genie_matrix_complex_minusab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_ROW_COMPLEX, M_ROW_ROW_COMPLEX, genie_matrix_complex_sub);
+  op_ab_torrix (p, M_REF_ROW_ROW_COMPLEX, M_ROW_ROW_COMPLEX, genie_matrix_complex_sub);
 }
 
 //! @brief OP * = ([] REAL, REAL) [] REAL
@@ -1149,28 +1397,28 @@ void genie_complex_scale_matrix_complex (NODE_T * p)
 
 void genie_vector_scale_real_ab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_REAL, M_REAL, genie_vector_scale_real);
+  op_ab_torrix (p, M_REF_ROW_REAL, M_REAL, genie_vector_scale_real);
 }
 
 //! @brief OP *:= (REF [, ] REAL, REAL) REF [, ] REAL
 
 void genie_matrix_scale_real_ab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_ROW_REAL, M_REAL, genie_matrix_scale_real);
+  op_ab_torrix (p, M_REF_ROW_ROW_REAL, M_REAL, genie_matrix_scale_real);
 }
 
 //! @brief OP *:= (REF [] COMPLEX, COMPLEX) REF [] COMPLEX
 
 void genie_vector_complex_scale_complex_ab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_COMPLEX, M_COMPLEX, genie_vector_complex_scale_complex);
+  op_ab_torrix (p, M_REF_ROW_COMPLEX, M_COMPLEX, genie_vector_complex_scale_complex);
 }
 
 //! @brief OP *:= (REF [, ] COMPLEX, COMPLEX) REF [, ] COMPLEX
 
 void genie_matrix_complex_scale_complex_ab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_ROW_COMPLEX, M_COMPLEX, genie_matrix_complex_scale_complex);
+  op_ab_torrix (p, M_REF_ROW_ROW_COMPLEX, M_COMPLEX, genie_matrix_complex_scale_complex);
 }
 
 //! @brief OP / = ([] REAL, REAL) [] REAL
@@ -1271,28 +1519,28 @@ void genie_matrix_complex_div_complex (NODE_T * p)
 
 void genie_vector_div_real_ab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_REAL, M_REAL, genie_vector_div_real);
+  op_ab_torrix (p, M_REF_ROW_REAL, M_REAL, genie_vector_div_real);
 }
 
 //! @brief OP /:= (REF [, ] REAL, REAL) REF [, ] REAL
 
 void genie_matrix_div_real_ab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_ROW_REAL, M_REAL, genie_matrix_div_real);
+  op_ab_torrix (p, M_REF_ROW_ROW_REAL, M_REAL, genie_matrix_div_real);
 }
 
 //! @brief OP /:= (REF [] COMPLEX, COMPLEX) REF [] COMPLEX
 
 void genie_vector_complex_div_complex_ab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_COMPLEX, M_COMPLEX, genie_vector_complex_div_complex);
+  op_ab_torrix (p, M_REF_ROW_COMPLEX, M_COMPLEX, genie_vector_complex_div_complex);
 }
 
 //! @brief OP /:= (REF [, ] COMPLEX, COMPLEX) REF [, ] COMPLEX
 
 void genie_matrix_complex_div_complex_ab (NODE_T * p)
 {
-  op_ab (p, M_REF_ROW_ROW_COMPLEX, M_COMPLEX, genie_matrix_complex_div_complex);
+  op_ab_torrix (p, M_REF_ROW_ROW_COMPLEX, M_COMPLEX, genie_matrix_complex_div_complex);
 }
 
 //! @brief OP * = ([] REAL, [] REAL) REAL
